aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/install/helper
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2016-12-02 11:36:07 +0100
committerMarc Alexander <admin@m-a-styles.de>2016-12-02 11:36:07 +0100
commit9bdd002f584de78475362067b777749486504172 (patch)
tree09e73db4f617adacdf22372f7285993644ab222e /phpBB/phpbb/install/helper
parent08bf8812d3bc7c22671e7e0dc88a0e99fcf403d7 (diff)
downloadforums-9bdd002f584de78475362067b777749486504172.tar
forums-9bdd002f584de78475362067b777749486504172.tar.gz
forums-9bdd002f584de78475362067b777749486504172.tar.bz2
forums-9bdd002f584de78475362067b777749486504172.tar.xz
forums-9bdd002f584de78475362067b777749486504172.zip
[ticket/14875] Move raw_variable() method to request_interface
PHPBB3-14875
Diffstat (limited to 'phpBB/phpbb/install/helper')
-rw-r--r--phpBB/phpbb/install/helper/iohandler/ajax_iohandler.php6
-rw-r--r--phpBB/phpbb/install/helper/iohandler/iohandler_interface.php4
2 files changed, 5 insertions, 5 deletions
diff --git a/phpBB/phpbb/install/helper/iohandler/iohandler_interface.php b/phpBB/phpbb/install/helper/iohandler/iohandler_interface.php
index f0e0e99bbb..440748901c 100644
--- a/phpBB/phpbb/install/helper/iohandler/iohandler_interface.php
+++ b/phpBB/phpbb/install/helper/iohandler/iohandler_interface.php
@@ -52,7 +52,7 @@ interface iohandler_interface
/**
* Returns server variable
*
- * This function should work the same as request_interterface::server().
+ * This function should work the same as request_interface::server().
*
* @param string $name Name of the server variable
* @param mixed $default Default value to return when the requested variable does not exist
@@ -62,7 +62,7 @@ interface iohandler_interface
public function get_server_variable($name, $default = '');
/**
- * Wrapper function for request_interterface::header()
+ * Wrapper function for request_interface::header()
*
* @param string $name Name of the request header variable
* @param mixed $default Default value to return when the requested variable does not exist
diff --git a/phpBB/phpbb/install/helper/iohandler/ajax_iohandler.php b/phpBB/phpbb/install/helper/iohandler/ajax_iohandler.php
index 2db6750f3f..a40d457466 100644
--- a/phpBB/phpbb/install/helper/iohandler/ajax_iohandler.php
+++ b/phpBB/phpbb/install/helper/iohandler/ajax_iohandler.php
@@ -27,7 +27,7 @@ class ajax_iohandler extends iohandler_base
protected $path_helper;
/**
- * @var \phpbb\request\request
+ * @var \phpbb\request\request_interface
*/
protected $request;
@@ -90,12 +90,12 @@ class ajax_iohandler extends iohandler_base
* Constructor
*
* @param path_helper $path_helper
* @param \phpbb\request\request $request HTTP request interface
* @param \phpbb\template\template $template Template engine
* @param router $router Router
* @param string $root_path Path to phpBB's root
*/
- public function __construct(path_helper $path_helper, \phpbb\request\request $request, \phpbb\template\template $template, router $router, $root_path)
+ public function __construct(path_helper $path_helper, \phpbb\request\request_interface $request, \phpbb\template\template $template, router $router, $root_path)
{
$this->path_helper = $path_helper;
$this->request = $request;
@@ -90,12 +90,12 @@ class ajax_iohandler extends iohandler_base
*
* @param path_helper $path_helper
- * @param \phpbb\request\request $request HTTP request interface
+ * @param \phpbb\request\request_interface $request HTTP request interface
* @param \phpbb\template\template $template Template engine
* @param router $router Router